@@ -6,12 +6,13 @@ Type annotations for workmailmessageflow service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
+    from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentRequestTypeDef
 
-    data: GetRawMessageContentResponseTypeDef = {...}
+    data: GetRawMessageContentRequestTypeDef = {...}
     ```
 """
 import sys
+from typing import Any, Dict
 
 from botocore.response import StreamingBody
 
@@ -21,12 +22,35 @@ else:
     from typing_extensions import TypedDict
 
 
-__all__ = ("GetRawMessageContentResponseTypeDef", "RawMessageContentTypeDef", "S3ReferenceTypeDef")
+__all__ = (
+    "GetRawMessageContentRequestTypeDef",
+    "GetRawMessageContentResponseResponseTypeDef",
+    "PutRawMessageContentRequestTypeDef",
+    "RawMessageContentTypeDef",
+    "ResponseMetadataTypeDef",
+    "S3ReferenceTypeDef",
+)
 
-GetRawMessageContentResponseTypeDef = TypedDict(
-    "GetRawMessageContentResponseTypeDef",
+GetRawMessageContentRequestTypeDef = TypedDict(
+    "GetRawMessageContentRequestTypeDef",
+    {
+        "messageId": str,
+    },
+)
+
+GetRawMessageContentResponseResponseTypeDef = TypedDict(
+    "GetRawMessageContentResponseResponseTypeDef",
     {
         "messageContent": StreamingBody,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+PutRawMessageContentRequestTypeDef = TypedDict(
+    "PutRawMessageContentRequestTypeDef",
+    {
+        "messageId": str,
+        "content": "RawMessageContentTypeDef",
     },
 )
 
@@ -37,6 +61,17 @@ RawMessageContentTypeDef = TypedDict(
     },
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredS3ReferenceTypeDef = TypedDict(
     "_RequiredS3ReferenceTypeDef",
     {
